import React from 'react';
import { PageType, Parameters } from '../../data/lib/Types';
/**
 * Dialog action data
 */
export interface DialogDataAction {
    value: any;
    label: string;
    theme?: 'inherit' | 'primary' | 'secondary' | 'success' | 'error' | 'info' | 'warning';
}
/**
 * Dialog data
 */
export interface DialogData {
    url?: string;
    content?: string | JSX.Element;
    dialogId?: number;
    addSelectField?: boolean;
    hideActions?: boolean;
    hideFilters?: boolean;
    hideDefaultFilters?: boolean;
    defaultValues?: Parameters;
    redirect?: PageType;
    title?: string;
    toolbar?: boolean;
    actions?: DialogDataAction[];
    width?: string;
    height?: string;
}
export interface DialogOptions {
    fullScreen?: boolean;
    small?: boolean;
    medium?: boolean;
    hasBackdrop?: boolean;
    closable?: boolean;
    alignItems?: any;
    justifyContent?: any;
    wrapContent?: boolean;
    expandableContent?: boolean;
}
interface DialogComponentProps {
    onRef: (c: DialogComponent) => {};
    mode: 'dialog' | 'drawer';
}
/**
 * Onka dialog component
 */
export declare class DialogComponent extends React.Component<DialogComponentProps, {
    show: boolean;
}> {
    /**
     * Url to display in iframe
     */
    url: string;
    data: DialogData;
    state: {
        show: boolean;
    };
    afterClosed?: (result?: any) => void;
    options: DialogOptions;
    constructor(props: DialogComponentProps);
    /**
     * Prepare data
     */
    init(): void;
    close(action?: DialogDataAction | any): void;
    open(config: DialogData, afterClosed?: (result?: any) => void, options?: DialogOptions): void;
    _inner(): string | JSX.Element;
    render(): import("react/jsx-runtime").JSX.Element;
}
export {};
