"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useForm = useForm;
exports.useFormHelper = useFormHelper;
var _react = require("react");
var _UseFormValidator = require("./UseFormValidator");
var _LibService = require("../services/LibService");
var _rxjs = require("rxjs");
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _unsupportedIterableToArray(arr, i) || _nonIterableRest(); }
function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }
function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }
function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i]; return arr2; }
function _iterableToArrayLimit(arr, i) { var _i = null == arr ? null : "undefined" != typeof Symbol && arr[Symbol.iterator] || arr["@@iterator"]; if (null != _i) { var _s, _e, _x, _r, _arr = [], _n = !0, _d = !1; try { if (_x = (_i = _i.call(arr)).next, 0 === i) { if (Object(_i) !== _i) return; _n = !1; } else for (; !(_n = (_s = _x.call(_i)).done) && (_arr.push(_s.value), _arr.length !== i); _n = !0); } catch (err) { _d = !0, _e = err; } finally { try { if (!_n && null != _i.return && (_r = _i.return(), Object(_r) !== _r)) return; } finally { if (_d) throw _e; } } return _arr; } }
function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function useForm() {
  var refProps = (0, _react.useRef)({});
  var refFormData = (0, _react.useRef)({});
  var refErrors = (0, _react.useRef)({});
  var formSubject = (0, _react.useRef)({});
  var errorSubject = (0, _react.useRef)({});
  var initForm = function initForm(props) {
    if (refFormData.current[props.formKey]) return;
    refProps.current[props.formKey] = props;
    refFormData.current[props.formKey] = props.initialValues;
    formSubject.current[props.formKey] = new _rxjs.Subject();
    errorSubject.current[props.formKey] = new _rxjs.Subject();
    if (props.initialValues) updateFormData(props.formKey, props.initialValues);
  };
  var clear = function clear() {
    refProps.current = {};
    refFormData.current = {};
    refErrors.current = {};
    formSubject.current = {};
    errorSubject.current = {};
  };
  var initInitialValues = function initInitialValues(formKey) {
    var _refProps$current$for;
    var initialValues = (_refProps$current$for = refProps.current[formKey]) === null || _refProps$current$for === void 0 ? void 0 : _refProps$current$for.initialValues;
    if (initialValues) updateFormData(formKey, initialValues);
  };
  var getErrors = function getErrors(formKey) {
    return refErrors.current[formKey] || {};
  };
  var setErrors = function setErrors(formKey, data) {
    refErrors.current[formKey] = data;
    errorSubject.current[formKey].next(data);
  };
  var getFormData = function getFormData(formKey) {
    return refFormData.current[formKey];
  };
  var setFormData = function setFormData(formKey, data) {
    refFormData.current[formKey] = data;
    formSubject.current[formKey].next(data);
  };
  var _useFormValidator = (0, _UseFormValidator.useFormValidator)({}),
    validate = _useFormValidator.validate;
  var handleSubmit = function handleSubmit(formKey, e) {
    e.preventDefault();
    var errorList = validate(refProps.current[formKey].fields, getFormData(formKey));
    if (errorList) {
      setErrors(formKey, errorList);
      return;
    }
    refProps.current[formKey].onSubmit && refProps.current[formKey].onSubmit(getFormData(formKey));
  };
  var getValue = function getValue(formKey, path) {
    return _LibService.LibService.instance().getValue(getFormData(formKey), path);
  };
  var getError = function getError(formKey, path) {
    return _LibService.LibService.instance().getValue(getErrors(formKey), path);
  };
  var updateFormData = function updateFormData(formKey, data) {
    if (!data) data = {};
    setFormData(formKey, data);
    formSubject.current[formKey].next(data);
  };
  var handleChanges = function handleChanges(formKey, values) {
    var dataCloned = _objectSpread({}, getFormData(formKey));
    for (var i = 0; i < values.length; i++) {
      var item = values[i];
      _LibService.LibService.instance().setValue(dataCloned, item.name, item.value);
    }
    setFormData(formKey, dataCloned);
    refProps.current[formKey].onAfterChanges && refProps.current[formKey].onAfterChanges();
  };
  var handleChange = function handleChange(formKey, name) {
    return function (value) {
      handleChanges(formKey, [{
        name: name,
        value: value
      }]);
    };
  };
  var subscribe = function subscribe(formKey, func) {
    return formSubject.current[formKey].subscribe(func);
  };
  var unsubscribe = function unsubscribe(subs) {
    subs.unsubscribe();
  };
  var subscribeError = function subscribeError(formKey, func) {
    return errorSubject.current[formKey].subscribe(func);
  };
  var unsubscribeError = function unsubscribeError(subs) {
    subs.unsubscribe();
  };
  (0, _react.useEffect)(function () {}, []);
  return {
    initForm: initForm,
    initInitialValues: initInitialValues,
    getFormData: getFormData,
    updateFormData: updateFormData,
    handleSubmit: handleSubmit,
    handleChange: handleChange,
    handleChanges: handleChanges,
    getErrors: getErrors,
    subscribe: subscribe,
    unsubscribe: unsubscribe,
    getValue: getValue,
    getError: getError,
    subscribeError: subscribeError,
    unsubscribeError: unsubscribeError,
    clear: clear
  };
}
function useFormHelper(props) {
  var _useState = (0, _react.useState)(props.defaultValue),
    _useState2 = _slicedToArray(_useState, 2),
    value = _useState2[0],
    setValue = _useState2[1];
  var _useState3 = (0, _react.useState)(''),
    _useState4 = _slicedToArray(_useState3, 2),
    error = _useState4[0],
    setError = _useState4[1];
  (0, _react.useEffect)(function () {
    var subscription = props.form.subscribe(props.formKey, function (data) {
      var rowData = props.form.getValue(props.formKey, props.path);
      if (props.preSetValue) setValue(props.preSetValue(rowData, props.defaultValue));else setValue(rowData || props.defaultValue);
    });
    var subscriptionError = props.form.subscribeError(props.formKey, function (data) {
      var errorData = props.form.getError(props.formKey, props.path);
      setError(errorData || '');
    });
    return function () {
      props.form.unsubscribe(subscription);
      props.form.unsubscribeError(subscriptionError);
    };
  }, []);
  return {
    value: value,
    error: error,
    setValue: setValue
  };
}
//# sourceMappingURL=UseForm.js.map