import { Subject } from 'rxjs';
import { ServiceHttpStatusResult, ServiceListResult } from '../../data/api/ServiceResult';
import { AxiosResponse, Method, AxiosRequestConfig } from 'axios';
import { Parameters } from '../../data/lib/Types';
/**
 * Bridge for request and response
 */
export declare class BaseBusinessLogicService {
    /**
     * Emit for all api response
     */
    apiResponse: Subject<ServiceHttpStatusResult<any>>;
    private constructor();
    private static _instance;
    static instance(): BaseBusinessLogicService;
    getHeaders(headers?: Parameters): Parameters;
    /**
     * Prepare data and parameters then make a request and validate the response
     * @param method method
     * @param endpoint endpoint
     * @param body body
     * @param parameters extra parameters
     * @param headers extra header
     */
    request<T>(method: Method, endpoint: string, body?: any, parameters?: Parameters, headers?: Parameters, options?: AxiosRequestConfig): Promise<ServiceHttpStatusResult<T>>;
    /**
     * Check response of the api
     * @param response http response object
     */
    processResponse<T>(response: AxiosResponse<ServiceListResult<T>>): Promise<ServiceHttpStatusResult<T>>;
    processError(reason: any): ServiceHttpStatusResult<any>;
}
