"use strict";

(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "../../data/models/ValidationModels", "../services/LocaleService", "../services/LibService"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("../../data/models/ValidationModels"), require("../services/LocaleService"), require("../services/LibService"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.ValidationModels, global.LocaleService, global.LibService);
    global.undefined = mod.exports;
  }
})(void 0, function (exports, _ValidationModels, _LocaleService, _LibService) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.useFormValidator = useFormValidator;
  function validate(fields, state) {
    if (!fields) return;
    var errorList = {};
    fields.forEach(function (field) {
      var _field$validators;
      var path = _LibService.LibService.instance().getPath(field.prefix, field.name);
      var value = _LibService.LibService.instance().getValue(state, field.name);
      (_field$validators = field.validators) === null || _field$validators === void 0 ? void 0 : _field$validators.forEach(function (validator) {
        var error = null;
        if (validator instanceof _ValidationModels.RequiredValidation) {
          if (value === null || value === '' || value === undefined) {
            error = _LocaleService.LocaleService.instance().translate('lib.validation.required');
          }
        } else if (validator instanceof _ValidationModels.EmailValidation) {
          if (value) {
            var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
            if (!re.test(String(value).toLowerCase())) {
              error = _LocaleService.LocaleService.instance().translate('lib.validation.email');
            }
          }
        } else if (validator instanceof _ValidationModels.ValueValidation) {
          var validation = validator;
          if (validation.type == 'minLength') {
            var _validation = validator;
            if ((value + '').length > _validation.value) {
              error = _LocaleService.LocaleService.instance().translate('lib.validation.minlength', undefined, {
                requiredLength: _validation.value
              });
            }
          } else if (validation.type == 'maxLength') {
            if ((value + '').length > validation.value) {
              error = _LocaleService.LocaleService.instance().translate('lib.validation.maxLength', undefined, {
                requiredLength: validation.value,
                actualLength: (value + '').length
              });
            }
          } else if (validation.type == 'min') {
            if (parseFloat(value) < validation.value) {
              error = _LocaleService.LocaleService.instance().translate('lib.validation.min', undefined, {
                min: validation.value
              });
            }
          } else if (validation.type == 'max') {
            if (parseFloat(value) > validation.value) {
              error = _LocaleService.LocaleService.instance().translate('lib.validation.max', undefined, {
                max: validation.value
              });
            }
          }
        }
        if (error) _LibService.LibService.instance().setValue(errorList, path, error);
      });
    });
    if (Object.keys(errorList).length > 0) {
      return errorList;
    }
  }
  function useFormValidator(props) {
    return {
      validate: validate
    };
  }
});
//# sourceMappingURL=UseFormValidator.js.map