"use strict";

(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "rxjs", "../helpers/RequestHelper", "./ConfigService", "./StaticService", "../../data/api/ServiceResult", "../../data/models/ApiError"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("rxjs"), require("../helpers/RequestHelper"), require("./ConfigService"), require("./StaticService"), require("../../data/api/ServiceResult"), require("../../data/models/ApiError"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.rxjs, global.RequestHelper, global.ConfigService, global.StaticService, global.ServiceResult, global.ApiError);
    global.undefined = mod.exports;
  }
})(void 0, function (exports, _rxjs, _RequestHelper, _ConfigService, _StaticService, _ServiceResult, _ApiError) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.BaseBusinessLogicService = void 0;
  function _typeof(obj) {
    "@babel/helpers - typeof";

    return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
      return typeof obj;
    } : function (obj) {
      return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    }, _typeof(obj);
  }
  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }
  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
    }
  }
  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }
  function _defineProperty(obj, key, value) {
    key = _toPropertyKey(key);
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }
    return obj;
  }
  function _toPropertyKey(arg) {
    var key = _toPrimitive(arg, "string");
    return _typeof(key) === "symbol" ? key : String(key);
  }
  function _toPrimitive(input, hint) {
    if (_typeof(input) !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
      var res = prim.call(input, hint || "default");
      if (_typeof(res) !== "object") return res;
      throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
  }
  /**
   * Bridge for request and response
   */
  var BaseBusinessLogicService = /*#__PURE__*/function () {
    function BaseBusinessLogicService() {
      _classCallCheck(this, BaseBusinessLogicService);
      /**
       * Emit for all api response
       */
      _defineProperty(this, "apiResponse", new _rxjs.Subject());
      this.processResponse = this.processResponse.bind(this);
    }
    _createClass(BaseBusinessLogicService, [{
      key: "getHeaders",
      value: function getHeaders(headers) {
        if (!headers) headers = {};
        if (_StaticService.StaticService.instance().getToken()) headers[_StaticService.StaticService.TOKEN_NAME] = _StaticService.StaticService.instance().getToken();
        return headers;
      }

      /**
       * Prepare data and parameters then make a request and validate the response
       * @param method method
       * @param endpoint endpoint
       * @param body body
       * @param parameters extra parameters
       * @param headers extra header
       */
    }, {
      key: "request",
      value: function request(method, endpoint, body, parameters, headers, options) {
        headers = this.getHeaders(headers);
        return _RequestHelper.RequestHelper.instance(_ConfigService.ConfigService.instance().getApiUrl()).request(method, endpoint, body, parameters, headers, options).then(this.processResponse).catch(this.processError);
      }

      /**
       * Check response of the api
       * @param response http response object
       */
    }, {
      key: "processResponse",
      value: function processResponse(response) {
        var _response$data, _response$data2, _response$data3, _response$data4, _response$data5;
        var result = new _ServiceResult.ServiceHttpStatusResult({
          status: response.status,
          statusText: response.statusText,
          success: (_response$data = response.data) === null || _response$data === void 0 ? void 0 : _response$data.success,
          code: (_response$data2 = response.data) === null || _response$data2 === void 0 ? void 0 : _response$data2.code,
          message: (_response$data3 = response.data) === null || _response$data3 === void 0 ? void 0 : _response$data3.message,
          value: (_response$data4 = response.data) === null || _response$data4 === void 0 ? void 0 : _response$data4.value,
          total: (_response$data5 = response.data) === null || _response$data5 === void 0 ? void 0 : _response$data5.total
        });
        this.apiResponse.next(result);
        if (result.status < 200 || result.status >= 300 || !result.success) {
          return Promise.reject(result);
        }
        return Promise.resolve(result);
      }
    }, {
      key: "processError",
      value: function processError(reason) {
        var _reason$response, _reason$response$data, _reason$response2, _reason$response2$dat, _reason$response3, _reason$response3$dat, _reason$response4, _reason$response4$dat, _reason$response5, _reason$response5$dat;
        console.log(reason);
        if (reason instanceof _ServiceResult.ServiceHttpStatusResult) {
          throw new _ApiError.ApiError(reason);
        }
        var result = new _ServiceResult.ServiceHttpStatusResult({
          status: 0,
          statusText: reason,
          success: ((_reason$response = reason.response) === null || _reason$response === void 0 ? void 0 : (_reason$response$data = _reason$response.data) === null || _reason$response$data === void 0 ? void 0 : _reason$response$data.success) || false,
          code: (_reason$response2 = reason.response) === null || _reason$response2 === void 0 ? void 0 : (_reason$response2$dat = _reason$response2.data) === null || _reason$response2$dat === void 0 ? void 0 : _reason$response2$dat.code,
          message: (_reason$response3 = reason.response) === null || _reason$response3 === void 0 ? void 0 : (_reason$response3$dat = _reason$response3.data) === null || _reason$response3$dat === void 0 ? void 0 : _reason$response3$dat.message,
          value: (_reason$response4 = reason.response) === null || _reason$response4 === void 0 ? void 0 : (_reason$response4$dat = _reason$response4.data) === null || _reason$response4$dat === void 0 ? void 0 : _reason$response4$dat.value,
          total: (_reason$response5 = reason.response) === null || _reason$response5 === void 0 ? void 0 : (_reason$response5$dat = _reason$response5.data) === null || _reason$response5$dat === void 0 ? void 0 : _reason$response5$dat.total
        });
        if (reason.response) {
          var _reason$response$data2;
          var json = reason.toJSON();
          console.log('error detail json', json);
          console.log('error detail response', reason.response);
          result.status = reason.response.status;
          result.statusText = reason.response.statusText || reason.response.data;
          result.message = json.message;
          if ((_reason$response$data2 = reason.response.data) !== null && _reason$response$data2 !== void 0 && _reason$response$data2.errors) {
            result.message = reason.response.data.title || '';
            for (var key in reason.response.data.errors) {
              for (var i = 0; i < reason.response.data.errors[key].length; i++) {
                result.message += "\n" + reason.response.data.errors[key][i];
              }
            }
          }
        } else if (reason instanceof Error) {
          var error = reason;
          result.message = error.message;
          result.statusText = error.stack;
        }
        if (result.status < 200 || result.status >= 300) {
          throw new _ApiError.ApiError(result);
        }
        return result;
      }
    }], [{
      key: "instance",
      value: function instance() {
        if (!this._instance) {
          this._instance = new BaseBusinessLogicService();
        }
        return this._instance;
      }
    }]);
    return BaseBusinessLogicService;
  }();
  exports.BaseBusinessLogicService = BaseBusinessLogicService;
});
//# sourceMappingURL=BaseBusinessLogic.js.map