"use strict";

(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "./LocaleService", "../../data/lib/PageConfig", "rxjs", "./StaticService", "./UIManager", "@loadable/component", "lodash/get", "lodash/set"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("./LocaleService"), require("../../data/lib/PageConfig"), require("rxjs"), require("./StaticService"), require("./UIManager"), require("@loadable/component"), require("lodash/get"), require("lodash/set"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.LocaleService, global.PageConfig, global.rxjs, global.StaticService, global.UIManager, global.component, global.get, global.set);
    global.undefined = mod.exports;
  }
})(void 0, function (exports, _LocaleService, _PageConfig, _rxjs, _StaticService, _UIManager) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.LibService = void 0;
  var _component = _interopRequireDefault();
  var _get = _interopRequireDefault();
  var _set = _interopRequireDefault();
  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : {
      default: obj
    };
  }
  function _typeof(obj) {
    "@babel/helpers - typeof";

    return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
      return typeof obj;
    } : function (obj) {
      return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    }, _typeof(obj);
  }
  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }
  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
    }
  }
  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }
  function _defineProperty(obj, key, value) {
    key = _toPropertyKey(key);
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }
    return obj;
  }
  function _toPropertyKey(arg) {
    var key = _toPrimitive(arg, "string");
    return _typeof(key) === "symbol" ? key : String(key);
  }
  function _toPrimitive(input, hint) {
    if (_typeof(input) !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
      var res = prim.call(input, hint || "default");
      if (_typeof(res) !== "object") return res;
      throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
  }
  /**
   * Contains business related the admin system
   */
  var LibService = /*#__PURE__*/function () {
    function LibService() {
      _classCallCheck(this, LibService);
      /**
       * Selected last page
       */
      _defineProperty(this, "selectedPage", new _rxjs.BehaviorSubject(new _PageConfig.PageConfig()));
      /**
       * Drawer state
       */
      _defineProperty(this, "drawerState", new _rxjs.BehaviorSubject(true));
      /**
       * Emits to refresh data
       */
      _defineProperty(this, "refreshPage", new _rxjs.Subject());
      this.localeService = _LocaleService.LocaleService.instance();
    }
    _createClass(LibService, [{
      key: "translate",
      value:
      /**
       * Get translatation by key
       */
      function translate(key, defaultValue, formatParams) {
        return this.localeService.translate(key, defaultValue, formatParams);
      }
      /**
       * Get translated enum
       * @param enumObj enum object
       * @param enumName enum name
       * @param val value
       */
    }, {
      key: "translatEnum",
      value: function translatEnum(enumObj, enumName, val) {
        var key = Object.keys(enumObj).filter(function (x) {
          return enumObj[x] == val;
        });
        if (key.length > 0) return this.translatEnumKey(enumName, key[0]);
        return null;
      }

      /**
       * Get translated text by enum key
       * @param enumName enum name
       * @param key key
       */
    }, {
      key: "translatEnumKey",
      value: function translatEnumKey(enumName, key) {
        return this.translate('enums.' + enumName + '.' + key, key);
      }

      /**
       * Get route translated labels
       */
    }, {
      key: "getRouteLabel",
      value: function getRouteLabel(pageConfig) {
        var name = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'name';
        if (!pageConfig) return '';
        return this.localeService.translate("resources.".concat(pageConfig.route, ".").concat(name), pageConfig.route);
      }
    }, {
      key: "getFieldLabel",
      value: function getFieldLabel(pageConfig, field) {
        field = field.replace(/(\[\d+\])/gim, '');
        return this.localeService.translate("resources.".concat(pageConfig.route, ".fields.").concat(field), field);
      }
    }, {
      key: "loadableComp",
      value: function loadableComp(imp, key) {
        return (0, _component.default)(function () {
          return imp().then(function (resp) {
            return resp[key];
          });
        });
        // return Loadable({
        //   loader: () =>
        //     imp()
        //       .then((a: any) => new Promise((resolve) => setTimeout(() => resolve(a), 50)))
        //       .then((resp: any) => resp[key]),
        //   loading() {
        //     return (
        //       <div className="progress">
        //         <div className="progress-bar bg-danger widthloop"></div>
        //       </div>
        //     );
        //   },
        // });
      }
    }, {
      key: "isSuperAdmin",
      value: function isSuperAdmin() {
        return _StaticService.StaticService.instance().isSuper();
      }
    }, {
      key: "hasAccess",
      value: function hasAccess(moduleKey, pageKey, actionKey) {
        if (this.isSuperAdmin()) return true;
        if (_StaticService.StaticService.instance().getRoles()[moduleKey + '_' + pageKey + '_admin']) return true;
        if (_StaticService.StaticService.instance().getRoles()[moduleKey + '_' + pageKey + '_' + actionKey]) return true;
        return false;
      }
    }, {
      key: "checkConfigPermision",
      value: function checkConfigPermision(pageConfig) {
        var _this = this;
        if (_UIManager.UIManager.instance().isHideActions()) {
          pageConfig.export = false;
          pageConfig.get = false;
          pageConfig.new = false;
          pageConfig.edit = false;
          pageConfig.delete = false;
        } else {
          var isOwner = this.hasAccess(pageConfig.moduleKey, pageConfig.pageKey, 'admin');
          ['export', 'get', 'new', 'edit', 'delete'].forEach(function (key) {
            // @ts-ignore
            pageConfig[key] = pageConfig[key] && (isOwner || _this.hasAccess(pageConfig.moduleKey, pageConfig.pageKey, key));
          });
        }
        return pageConfig;
      }
    }, {
      key: "getPath",
      value: function getPath(prefix, name) {
        return (prefix || '') + (name || '');
      }
    }, {
      key: "getFieldValue",
      value: function getFieldValue(data, prefix, name) {
        return (0, _get.default)(data, this.getPath(prefix, name));
      }
    }, {
      key: "getValue",
      value: function getValue(data, path) {
        return (0, _get.default)(data, path);
      }
    }, {
      key: "setValue",
      value: function setValue(data, path, value) {
        return (0, _set.default)(data, path, value);
      }
    }, {
      key: "filterFields",
      value: function filterFields(pageFields, pageType, prefix) {
        var fields = pageFields.filter(function (x) {
          if (pageType == 'edit') return x.displayInEdit;
          if (pageType == 'create') return x.displayInCreate;
          if (pageType == 'detail') return x.displayInDetail;
          return false;
        });
        if (prefix) {
          fields.forEach(function (field) {
            field.prefix = prefix;
          });
        }
        return fields;
      }
    }], [{
      key: "instance",
      value: function instance() {
        if (!this._instance) {
          this._instance = new LibService();
        }
        return this._instance;
      }
    }]);
    return LibService;
  }();
  exports.LibService = LibService;
});
//# sourceMappingURL=LibService.js.map