"use strict";

(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "./ConfigService", "./StaticService", "lodash", "../../assets/l10n/en.json"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("./ConfigService"), require("./StaticService"), require("lodash"), require("../../assets/l10n/en.json"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.ConfigService, global.StaticService, global.lodash, global.en);
    global.undefined = mod.exports;
  }
})(void 0, function (exports, _ConfigService, _StaticService) {
  "use strict";

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports.LocaleService = void 0;
  var lodash = _interopRequireWildcard();
  var _en = _interopRequireWildcard();
  function _getRequireWildcardCache(nodeInterop) {
    if (typeof WeakMap !== "function") return null;
    var cacheBabelInterop = new WeakMap();
    var cacheNodeInterop = new WeakMap();
    return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) {
      return nodeInterop ? cacheNodeInterop : cacheBabelInterop;
    })(nodeInterop);
  }
  function _interopRequireWildcard(obj, nodeInterop) {
    if (!nodeInterop && obj && obj.__esModule) {
      return obj;
    }
    if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return {
        default: obj
      };
    }
    var cache = _getRequireWildcardCache(nodeInterop);
    if (cache && cache.has(obj)) {
      return cache.get(obj);
    }
    var newObj = {};
    var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;
    for (var key in obj) {
      if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;
        if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }
    newObj.default = obj;
    if (cache) {
      cache.set(obj, newObj);
    }
    return newObj;
  }
  function _typeof(obj) {
    "@babel/helpers - typeof";

    return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) {
      return typeof obj;
    } : function (obj) {
      return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    }, _typeof(obj);
  }
  function _classCallCheck(instance, Constructor) {
    if (!(instance instanceof Constructor)) {
      throw new TypeError("Cannot call a class as a function");
    }
  }
  function _defineProperties(target, props) {
    for (var i = 0; i < props.length; i++) {
      var descriptor = props[i];
      descriptor.enumerable = descriptor.enumerable || false;
      descriptor.configurable = true;
      if ("value" in descriptor) descriptor.writable = true;
      Object.defineProperty(target, _toPropertyKey(descriptor.key), descriptor);
    }
  }
  function _createClass(Constructor, protoProps, staticProps) {
    if (protoProps) _defineProperties(Constructor.prototype, protoProps);
    if (staticProps) _defineProperties(Constructor, staticProps);
    Object.defineProperty(Constructor, "prototype", {
      writable: false
    });
    return Constructor;
  }
  function _defineProperty(obj, key, value) {
    key = _toPropertyKey(key);
    if (key in obj) {
      Object.defineProperty(obj, key, {
        value: value,
        enumerable: true,
        configurable: true,
        writable: true
      });
    } else {
      obj[key] = value;
    }
    return obj;
  }
  function _toPropertyKey(arg) {
    var key = _toPrimitive(arg, "string");
    return _typeof(key) === "symbol" ? key : String(key);
  }
  function _toPrimitive(input, hint) {
    if (_typeof(input) !== "object" || input === null) return input;
    var prim = input[Symbol.toPrimitive];
    if (prim !== undefined) {
      var res = prim.call(input, hint || "default");
      if (_typeof(res) !== "object") return res;
      throw new TypeError("@@toPrimitive must return a primitive value.");
    }
    return (hint === "string" ? String : Number)(input);
  }
  /**
   * Localization service
   */
  var LocaleService = /*#__PURE__*/function () {
    function LocaleService() {
      _classCallCheck(this, LocaleService);
      /**
       * Json content of l10n
       */
      _defineProperty(this, "jsonContent", {});
      /**
       * Language list
       */
      _defineProperty(this, "langList", {
        en: function en() {
          return Promise.resolve(_en);
        }
      });
    } // get extended langs
    _createClass(LocaleService, [{
      key: "getCurrentLang",
      value: function getCurrentLang() {
        return _StaticService.StaticService.instance().getCurrentLang();
      }

      /**
       * Load default language
       */
    }, {
      key: "loadDefaultLang",
      value: function loadDefaultLang() {
        var lang = _StaticService.StaticService.instance().getCurrentLang();
        return this.changeLang(lang);
      }

      /**
       * Change selected language
       * @param lang language
       */
    }, {
      key: "changeLang",
      value: function changeLang(lang) {
        var _this = this;
        if (!lang) lang = 'en';
        _StaticService.StaticService.instance().setCurrentLang(lang);
        if (!this.langList[lang]) lang = 'en';
        var part1 = this.langList[lang];
        var part2 = _ConfigService.ConfigService.instance().getLangList()[lang];
        if (!part1) return Promise.reject();
        return part1().then(function (data) {
          _this.jsonContent = data.default;
        }).then(function () {
          if (part2) return part2();
        }).then(function (newData) {
          if (!newData) return;
          _this.jsonContent = lodash.merge(_this.jsonContent, newData);
        }).catch(function (error) {
          return Promise.resolve();
        });
      }

      /**
       * get content by key
       * @param key key
       * @param defaultValue default value
       */
    }, {
      key: "get",
      value: function get(key, defaultValue) {
        var r = lodash.get(this.jsonContent, key, defaultValue);
        return r;
      }

      /**
       * Get translation by key
       * @param key key
       * @param defaultValue default value
       * @param formatParams parameters to replace, like; { title: 'Hello' }
       */
    }, {
      key: "translate",
      value: function translate(key, defaultValue, formatParams) {
        if (!formatParams) return this.get(key, defaultValue);
        return lodash.template(this.get(key, defaultValue))(formatParams);
      }
    }, {
      key: "getValue",
      value: function getValue(key) {
        var keys = key.split('.');
        var root = this.jsonContent;
        for (var i = 0; i < keys.length; i++) {
          root = root[keys[i]];
          if (!root) return;
        }
        return root;
      }
    }], [{
      key: "instance",
      value: function instance() {
        if (!this._instance) {
          this._instance = new LocaleService();
        }
        return this._instance;
      }
    }]);
    return LocaleService;
  }();
  exports.LocaleService = LocaleService;
});
//# sourceMappingURL=LocaleService.js.map